@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Patch.py 11459 2019-04-16 18:20:57Z Lavender $
+# $Id: Patch.py 11526 2019-05-07 08:36:46Z Andy $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,27 +11,19 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $ (last)
-# $Date: 2019-04-17 03:20:57 +0900 (週三, 17 四月 2019) $
-# $Revision: 11459 $
+# $Author: Andy $ (last)
+# $Date: 2019-05-07 17:36:46 +0900 (週二, 07 五月 2019) $
+# $Revision: 11526 $
 #
 # Contributors:
 #  Bear
 #  Yachu
 
 from Iuppiter.DjangoUtil import (
-    extendInstalledApps, extendMiddlewareClasses, DJANGO_VERSION)
+    extendInstalledApps, extendMiddlewareClasses, DJANGO_VERSION, patterns)
 
 from .Util import update, populateEnvToSettings
 
-def patterns(prefix, *args): 
-    if DJANGO_VERSION >= 11100: # django >= 1.11
-        return list(args)
-    else:
-        from django.conf.urls import patterns as _patterns
-        
-        return _patterns(prefix, *args)
-
 def attachDebugSettings(settingsDict):
     """
     Attach debug related settings to settings.py.
