@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11551 2019-05-15 12:12:43Z Lavender $
+# $Id: __init__.py 11563 2019-05-20 02:06:32Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2019-05-15 21:12:43 +0900 (週三, 15 五月 2019) $
-# $Revision: 11551 $
+# $Date: 2019-05-20 11:06:32 +0900 (週一, 20 五月 2019) $
+# $Revision: 11563 $
 
 import os
 import sys
@@ -594,7 +594,12 @@ CATHAYBK = 'cathaybk'
 
 class AllPay2(AllPay):
     def __init__(self, paymentConf, serviceMethod='post'):
-        super(AllPay2, self).__init__(paymentConf, service_method=serviceMethod)
+        if six.PY2:
+            # super() argument 1 must be type, not classobj
+            AllPay.__init__(self, paymentConf, service_method=serviceMethod)
+        else:
+            super(AllPay2, self).__init__(
+                paymentConf, service_method=serviceMethod)
         if 'Language' in paymentConf:
             self.url_dict['Language'] = paymentConf['Language']
 
@@ -748,7 +753,10 @@ def buildAPIForm(submission, request, apiName, extra={}):
             'TradeDesc' : settings.OSCAR_SHOP_NAME, 
             'Remark' : settings.OSCAR_SHOP_NAME,
         }
-
+        
+        if apiName == ECPAY and submission['order_total'].currency == 'USD':
+            data['Language'] = 'ENG'
+            
         if apiName == ECPAY and hasattr(settings, 'ECPAY_LANGUAGE'):
             data['Language'] = settings.ECPAY_LANGUAGE
         
